@@ -28,25 +28,21 @@ class Comparer:
         self.end_time = None
         self.total_remote_files = None
         self.remote_files_processed = 0
-        self.has_errors = False
+        self.errors = []
 
     def start(self):
         self.total_remote_files = None
         self.remote_files_processed = 0
-        self.has_errors = False
+        self.errors = []
 
         if SynapseProxy.logged_in() or SynapseProxy.login(username=self._username, password=self._password):
             AioManager.start(self._startAsync)
         else:
-            self.has_errors = True
+            self._log_error('Could not login to Synapse.')
 
         self.end_time = datetime.now()
         self._log_info('Run time: {0}'.format(self.end_time - (self.start_time or datetime.now())))
-
-        if self.has_errors:
-            logging.error('Finished with errors. See log file.')
-        else:
-            logging.info('Finished successfully.')
+        return self
 
     async def _startAsync(self):
         try:
@@ -79,7 +75,7 @@ class Comparer:
             self._log_error('Unknown error. See log file.')
 
     def _log_error(self, *msg):
-        self.has_errors = True
+        self.errors.append('\n'.join(msg))
         logging.error('\n'.join(msg))
 
     def _log_info(self, *msg):
@@ -125,7 +121,18 @@ class Comparer:
 
                 remote_size = remote_file['content_size']
                 local_size = os.path.getsize(local_match.path)
-                if local_size != remote_size:
+                # NOTE: For ExternalFileHandles the size and MD5 data will not be present.
+                is_unknown_size = remote_size is None
+
+                if is_unknown_size:
+                    # TODO: Should we download the ExternalFileHandle and check its size?
+                    self._log_info('[REMOTE SIZE UNKNOWN]',
+                                   '  REMOTE [?]: {0}({1}) ({2})'.format(remote_file['name'],
+                                                                         remote_file['id'],
+                                                                         Utils.pretty_size(remote_size)),
+                                   '  LOCAL  [+]: {0} ({1})'.format(local_match.path, Utils.pretty_size(local_size)),
+                                   '')
+                elif local_size != remote_size:
                     self._log_error('[SIZE MISMATCH]',
                                     '  REMOTE [-]: {0}({1}) ({2})'.format(remote_file['name'],
                                                                           remote_file['id'],
